summaryrefslogtreecommitdiff
path: root/libopie2/opiepim/backend/ocontactaccessbackend_xml.h
Side-by-side diff
Diffstat (limited to 'libopie2/opiepim/backend/ocontactaccessbackend_xml.h') (more/less context) (ignore whitespace changes)
-rw-r--r--libopie2/opiepim/backend/ocontactaccessbackend_xml.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/libopie2/opiepim/backend/ocontactaccessbackend_xml.h b/libopie2/opiepim/backend/ocontactaccessbackend_xml.h
index f439c4c..eaea352 100644
--- a/libopie2/opiepim/backend/ocontactaccessbackend_xml.h
+++ b/libopie2/opiepim/backend/ocontactaccessbackend_xml.h
@@ -21,88 +21,88 @@
: = ...= . :.=-
-. .:....=;==+<; You should have received a copy of the GNU
-_. . . )=. = Library General Public License along with
-- :-=` this library; see the file COPYING.LIB.
If not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.
*/
/*
* XML Backend for the OPIE-Contact Database.
*/
-#ifndef _OContactAccessBackend_XML_
-#define _OContactAccessBackend_XML_
+#ifndef _OPimContactAccessBackend_XML_
+#define _OPimContactAccessBackend_XML_
#include <opie2/ocontactaccessbackend.h>
#include <opie2/ocontactaccess.h>
#include <qlist.h>
#include <qdict.h>
namespace Opie {
/* the default xml implementation */
/**
* This class is the XML implementation of a Contact backend
* it does implement everything available for OContact.
* @see OPimAccessBackend for more information of available methods
*/
-class OContactAccessBackend_XML : public OContactAccessBackend {
+class OPimContactAccessBackend_XML : public OPimContactAccessBackend {
public:
- OContactAccessBackend_XML ( const QString& appname, const QString& filename = QString::null );
+ OPimContactAccessBackend_XML ( const QString& appname, const QString& filename = QString::null );
bool save();
bool load ();
void clear ();
bool wasChangedExternally();
QArray<int> allRecords() const;
- OContact find ( int uid ) const;
+ OPimContact find ( int uid ) const;
- QArray<int> queryByExample ( const OContact &query, int settings, const QDateTime& d = QDateTime() );
+ QArray<int> queryByExample ( const OPimContact &query, int settings, const QDateTime& d = QDateTime() );
QArray<int> matchRegexp( const QRegExp &r ) const;
const uint querySettings();
bool hasQuerySettings (uint querySettings) const;
// Currently only asc implemented..
QArray<int> sorted( bool asc, int , int , int );
- bool add ( const OContact &newcontact );
+ bool add ( const OPimContact &newcontact );
- bool replace ( const OContact &contact );
+ bool replace ( const OPimContact &contact );
bool remove ( int uid );
bool reload();
private:
enum journal_action { ACTION_ADD, ACTION_REMOVE, ACTION_REPLACE };
- void addContact_p( const OContact &newcontact );
+ void addContact_p( const OPimContact &newcontact );
/* This function loads the xml-database and the journalfile */
bool load( const QString filename, bool isJournal );
- void updateJournal( const OContact& cnt, journal_action action );
+ void updateJournal( const OPimContact& cnt, journal_action action );
void removeJournal();
protected:
bool m_changed;
QString m_journalName;
QString m_fileName;
QString m_appName;
- QList<OContact> m_contactList;
+ QList<OPimContact> m_contactList;
QDateTime m_readtime;
- QDict<OContact> m_uidToContact;
+ QDict<OPimContact> m_uidToContact;
};
}
#endif
@@ -21,88 +21,88 @@
/**
* This class is the XML implementation of a Contact backend
- * it does implement everything available for OContact.
+ * it does implement everything available for OPimContact.
* @see OPimAccessBackend for more information of available methods
*/